Panya Tube
==========

Panya tube(channel, show, clip) app.

System Package Dependencies
---------------------------

#. cython (install using system easy_install)
#. ffmpeg
#. libavcodec-dev
#. libavformat-dev
#. libavutil-dev
#. python-dev
#. python-Pyrex

